@@ -505,10 +505,13 @@ derivePHMM.default <- function(x, seqweights = "Henikoff", wfactor = 1, k = 5,
   if(is.null(seqweights)){
     seqweights <- rep(1, n)
   }else if(identical(seqweights, "Gerstein") | identical(seqweights, "Henikoff")){
-    seqweights <- if(n > 2){
-      weight(unalign(x, gap = gap), method = seqweights, k = k, residues = residues, gap = gap)
+    seqlist <- unalign(x, gap = gap)
+    seqlengths <- vapply(seqlist, length, 0L)
+    if(n > 2 & min(seqlengths) > k + 1L){
+      seqweights <- weight(seqlist, method = seqweights, k = k, residues = residues, gap = gap)
     }else{
-      rep(1, n)
+      if(!quiet) cat("Applying uniform sequence weights\n")
+      seqweights <- rep(1, n)
     }
   }else{
     stopifnot(
@@ -612,7 +615,7 @@ derivePHMM.default <- function(x, seqweights = "Henikoff", wfactor = 1, k = 5,
   xtr <- cbind(1L, xtr, 1L) # append begin and end match states
   tcs <- .atab(xtr, seqweights = seqweights)
   rm(xtr)
-  gc()
+  #gc()
   alltcs <- apply(tcs, 1, sum) + 1 # forced addition of Laplacian pseudos
   ### background transition probs
   if(is.null(qa)){
@@ -711,7 +714,7 @@ derivePHMM.default <- function(x, seqweights = "Henikoff", wfactor = 1, k = 5,
     res$alignment <- x
   }
   if(compo) res$compo <- log(apply(exp(E), 1, mean))
-  gc()
+  #gc()
   # if(!quiet) cat("Done\n")
   return(res)
 }
@@ -935,7 +938,7 @@ map <- function(x, seqweights = NULL, residues = NULL,
     }
     res <- res[-(c(1, L + 2))]
   }
-  gc()
+  #gc()
   return(res)
 }
 ################################################################################
